==> hudder-8.5.1-sources.jar: dev/ngspace/ngsmcconfig/gui/NGSMCConfigEntry.java <==
package dev.ngspace.ngsmcconfig.gui;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1144;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_364;
import net.minecraft.class_4185;
import net.minecraft.class_4265;
import net.minecraft.class_6379;
import net.minecraft.class_7842;
import dev.ngspace.ngsmcconfig.options.AbstractNGSMCConfigOption;

public class NGSMCConfigEntry extends class_4265.class_4266<NGSMCConfigEntry>{
	
    class_339 widget;
    class_4185 resetButton;
    class_7842 text;
    
    List<class_339> children;
	private AbstractNGSMCConfigOption<?> option;
    
    protected NGSMCConfigEntry() {}

    public NGSMCConfigEntry(class_339 widget, class_2561 title, AbstractNGSMCConfigOption<?> option) {
        this.widget = widget;
        resetButton = class_4185.method_46430(class_2561.method_43471("ngsmcconfig.reset"), button->option.reset())
        		.method_46437(40, 20).method_46431();
        text = new class_7842(0, 0, 200, 20, title, class_310.method_1551().field_1772) {
        	@Override public void method_25354(class_1144 soundManager) { /* Ugly noise */ }
        };
        text.method_48596();
        text.field_22763 = true;
        this.option = option;
        children = Arrays.asList(widget, resetButton, text);
    }

    @Override
    public void method_25343(class_332 graphics, int index, int y, int x, int width, int height, int mouseX, int mouseY,
    		boolean hovered, float partialTick) {
    	resetButton.method_48229(x+width-40, y);
        resetButton.method_25394(graphics, mouseX, mouseY, partialTick);
        resetButton.field_22763 = !option.isDefault();
        if (widget!=null) {
        	widget.method_48229(x+width-50-widget.method_25368(), y);
        	widget.method_25394(graphics, mouseX, mouseY, partialTick);
        }
        text.method_48229(x, y);
        text.method_25394(graphics, mouseX, mouseY, partialTick);
        var c = method_19355(mouseX, mouseY);
        if (c.isPresent()) {
        	var child = c.get();
        	if (child==text) {
        		text.method_48579(graphics, height, mouseY, partialTick);
        	}
        }
        
    	var hoveredwidget = this.method_19355(mouseX, mouseY);
        
        if (hoveredwidget.isPresent() && hoveredwidget.get() instanceof class_339 hoveredawidget) {
            class_2583 style = hoveredawidget.method_25369().method_10866();
            graphics.method_51441(class_310.method_1551().field_1772, style, mouseX-5, mouseY+10);
        }
    }

    @Override public List<? extends class_364> method_25396() {return children;}

	@Override public List<? extends class_6379> method_37025() {return children;}
}

==> hudder-8.6.0-sources.jar: dev/ngspace/ngsmcconfig/gui/NGSMCConfigEntry.java <==
package dev.ngspace.ngsmcconfig.gui;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1144;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_364;
import net.minecraft.class_4185;
import net.minecraft.class_4265;
import net.minecraft.class_6379;
import net.minecraft.class_7842;
import dev.ngspace.ngsmcconfig.options.AbstractNGSMCConfigOption;

public class NGSMCConfigEntry extends class_4265.class_4266<NGSMCConfigEntry>{
	
    class_339 widget;
    class_4185 resetButton;
    class_7842 text;
    
    List<class_339> children;
	private AbstractNGSMCConfigOption<?> option;
    
    protected NGSMCConfigEntry() {}

    public NGSMCConfigEntry(class_339 widget, class_2561 title, AbstractNGSMCConfigOption<?> option) {
        this.widget = widget;
        resetButton = class_4185.method_46430(class_2561.method_43471("ngsmcconfig.reset"), button->option.reset())
        		.method_46437(40, 20).method_46431();
        text = new class_7842(0, 0, 200, 20, title, class_310.method_1551().field_1772) {
        	@Override public void method_25354(class_1144 soundManager) { /* Ugly noise */ }
        };
//        text.alignLeft();
        text.field_22763 = true;
        this.option = option;
        children = Arrays.asList(widget, resetButton, text);
    }

    @Override
    public void method_25343(class_332 graphics, int mouseX, int mouseY, boolean hovered, float partialTick) {
    	int x = method_46426();
    	int width = method_25368();
    	int height = method_25364();
    	int y = method_46427();
    	resetButton.method_48229(x+width-40, y);
        resetButton.method_25394(graphics, mouseX, mouseY, partialTick);
        resetButton.field_22763 = !option.isDefault();
        if (widget!=null) {
        	widget.method_48229(x+width-50-widget.method_25368(), y);
        	widget.method_25394(graphics, mouseX, mouseY, partialTick);
        }
        text.method_48229(x, y);
        text.method_25394(graphics, mouseX, mouseY, partialTick);
        var c = method_19355(mouseX, mouseY);
        if (c.isPresent()) {
        	var child = c.get();
        	if (child==text) {
        		text.method_48579(graphics, height, mouseY, partialTick);
        	}
        }
        
    	var hoveredwidget = this.method_19355(mouseX, mouseY);
        
        if (hoveredwidget.isPresent() && hoveredwidget.get() instanceof class_339 hoveredawidget) {
            class_2583 style = hoveredawidget.method_25369().method_10866();
            graphics.method_51441(class_310.method_1551().field_1772, style, mouseX-5, mouseY+10);
        }
    }

    @Override public List<? extends class_364> method_25396() {return children;}

	@Override public List<? extends class_6379> method_37025() {return children;}
}
